%% Hierarchical Stopping Rules
clear;

run_model=0; % set 0 to load samples, or 1 to run WinBUGS

%% Load Data
load DecisionData_2 y p m v x
% y is 20x100 binary decision data for subjects by problems
% m is 83x9 stimulus by cue matrix defining German cities
% p is a 100x2 problem matrix, giving the city numbers for all 100 questions
% v is 9x1 vector of cue validities
% x is 9x1 vector of log-odds evidence implied by validities

% Constants
[n nc]=size(m); % number of stimuli and cues
[nq junk]=size(p); % number of questions
[ns junk]=size(y); % number of subjects


%% WinBUGS
% WinBUGS Sampling Parameters
nchains=2; 
nburnin=1e3; 
nsamples=2e3; 

% Data to Supply to WinBugs
datastruct = struct('ns',ns,'nc',nc,'nq',nq,'m',m,'p',p,'y',y,'v',v,'x',x);

% Initial Values to Supply to WinBugs
for i=1:nchains
tmp=[zeros(ns/2,1) ones(ns/2,1)];
tmp=tmp(randperm(ns));
    S.gamma = 0.95;
    S.phi =0.5;
    S.z = tmp;
    S.mutmp = 1;
    S.delta= 1;
    S.sigma = ones(2,1);
	init0(i) = S;
end

if ~run_model
    load Stop_2 samples stats
else
    % Use WinBUGS to Sample
[samples, stats] = matbugs(datastruct, ...
    fullfile(pwd, 'Stop_2.txt'), ...
    'init', init0, ...
    'nChains', nchains, ...
    'view', 0, 'nburnin', nburnin, 'nsamples', nsamples, ...
    'thin', 1, 'DICstatus', 0, 'refreshrate',1, ...
    'monitorParams', {'gamma','z','alpha','mu','sigma','phi','predv','t'}, ...
    'Bugdir', 'C:/Program Files/WinBUGS14');
%save Stop_2 samples stats
end;

%% Analysis
% Answers on 0-1 Scale
answers=zeros(ns,nq);
for i=1:ns
    for j=1:nq
        answers(i,j)=mode(reshape(samples.t(:,:,i,j),1,[]));
    end;
end;
answers=round((answers-1)/2);
% Proportion Correct
correct=sum(sum(answers==y))/ns/nq;
% Plot
figure(4);clf;hold on;
set(gcf,'units','norm','pos',[.2 .2 .6 .5],'paperpositionmode','auto');
axis([0 nq+1 0 ns+1]);
for i=1:nq
    for j=1:ns
        if y(j,i)==0
            ph=plot(i,j,'k+');
        end;
        if answers(j,i)==0
            ph=plot(i,j,'kx');
            set(ph,'markersize',8);
        end;
    end;
end;
set(gca,'fontsize',14,'box','on','ticklength',[0 0],'xtick',[1 12 20:10:90 96]);
xlabel('Question','fontsize',16);
ylabel('Subject','fontsize',16);